==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QAlphaCoverage.java <==
package io.qt.qt3d.render;


/**
 * <p>Enable alpha-to-coverage multisampling mode</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qalphacoverage.html">Qt3DRender::QAlphaCoverage</a></p>
 */
public class QAlphaCoverage extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAlphaCoverage.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAlphaCoverage(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAlphaCoverage() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qalphacoverage.html#QAlphaCoverage">Qt3DRender::QAlphaCoverage::QAlphaCoverage(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAlphaCoverage(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAlphaCoverage instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAlphaCoverage(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAlphaCoverage(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAlphaCoverage instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.3.4-sources.jar: io/qt/qt3d/render/QAlphaCoverage.java <==
package io.qt.qt3d.render;


/**
 * <p>Enable alpha-to-coverage multisampling mode</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qalphacoverage.html">Qt3DRender::QAlphaCoverage</a></p>
 */
public class QAlphaCoverage extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAlphaCoverage.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QAlphaCoverage(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QAlphaCoverage() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qalphacoverage.html#QAlphaCoverage">Qt3DRender::QAlphaCoverage::QAlphaCoverage(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QAlphaCoverage(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QAlphaCoverage instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAlphaCoverage(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QAlphaCoverage(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QAlphaCoverage instance, QDeclarativeConstructor constructor);
    
}
